@@ -2,7 +2,11 @@
 #include <config.h>
 #endif
 
+#ifdef GNOME_GTKHTML_EDITOR_SHLIB
+#include <glib/gi18n-lib.h>
+#else
 #include <glib/gi18n.h>
+#endif
 #include <string.h>
 #include <gnome.h>
 #include <bonobo.h>
@@ -13,13 +17,14 @@
 #include <sys/stat.h>
 #include <fcntl.h>
 
-#include <gtk/gtkscrolledwindow.h>
+#include <gtk/gtk.h>
 
 #include <glade/glade.h>
 
 #include "Editor.h"
 
 #include "gtkhtml.h"
+#include "gtkhtml-private.h"
 #include "gtkhtml-properties.h"
 #include "htmlcursor.h"
 #include "htmlengine.h"
@@ -60,12 +65,13 @@ main (int argc, char **argv)
 #endif
 
 	/* Initialize the i18n support */
+	textdomain (GETTEXT_PACKAGE);
 	bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 
-	gnome_program_init(PACKAGE, VERSION, LIBGNOMEUI_MODULE, argc, argv, 
+	gnome_program_init(PACKAGE, VERSION, LIBGNOMEUI_MODULE, argc, argv,
 			   GNOME_PROGRAM_STANDARD_PROPERTIES,
-			   GNOME_PARAM_HUMAN_READABLE_NAME, _("GtkHTML Editor Control"),			   
+			   GNOME_PARAM_HUMAN_READABLE_NAME, _("GtkHTML Editor Control"),
 			   NULL);
 
 	/* #ifdef GTKHTML_HAVE_GCONF
@@ -80,7 +86,7 @@ main (int argc, char **argv)
 
 	if (factory) {
 		bonobo_running_context_auto_exit_unref (BONOBO_OBJECT (factory));
-	
+
 		bonobo_activate ();
 		bonobo_main ();
 
